summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
diff options
context:
space:
mode:
authorwittman@chromium.org <wittman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-03 00:41:58 +0000
committerwittman@chromium.org <wittman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-03 00:41:58 +0000
commitd2b1657066dd75dae77a79f0d27b33c2eb708e3b (patch)
tree0fa11dccf1e81084eca2943bf7e61f3a9059a338 /chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
parent937c4ebd57998c1fac40e5f9ed80cb8867ac661e (diff)
downloadchromium_src-d2b1657066dd75dae77a79f0d27b33c2eb708e3b.zip
chromium_src-d2b1657066dd75dae77a79f0d27b33c2eb708e3b.tar.gz
chromium_src-d2b1657066dd75dae77a79f0d27b33c2eb708e3b.tar.bz2
Rename platform-independent ConstrainedWindow types to WebContentsModalDialog types (part 2). See https://codereview.chromium.org/11647017/ for part 1.
This performs the actual class/filename renames. No functional changes are intended in this CL. R=sky@chromium.org BUG=157161 Review URL: https://chromiumcodereview.appspot.com/11633052 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@174900 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h')
-rw-r--r--chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h b/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
index c814c7d..3fcc0fb 100644
--- a/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
+++ b/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h
@@ -29,7 +29,7 @@ class ConstrainedWebDialogDelegateBase
WebDialogWebContentsDelegate* tab_delegate);
virtual ~ConstrainedWebDialogDelegateBase();
- void set_window(ConstrainedWindow* window);
+ void set_window(WebContentsModalDialog* window);
bool closed_via_webui() const;
// ConstrainedWebDialogDelegate interface.
@@ -38,7 +38,7 @@ class ConstrainedWebDialogDelegateBase
virtual ui::WebDialogDelegate* GetWebDialogDelegate() OVERRIDE;
virtual void OnDialogCloseFromWebUI() OVERRIDE;
virtual void ReleaseWebContentsOnDialogClose() OVERRIDE;
- virtual ConstrainedWindow* GetWindow() OVERRIDE;
+ virtual WebContentsModalDialog* GetWindow() OVERRIDE;
virtual content::WebContents* GetWebContents() OVERRIDE;
// WebDialogWebContentsDelegate interface.
@@ -53,8 +53,9 @@ class ConstrainedWebDialogDelegateBase
private:
scoped_ptr<ui::WebDialogDelegate> web_dialog_delegate_;
- // The constrained window that owns |this|. Saved so we can close it later.
- ConstrainedWindow* window_;
+ // The web contents modal dialog that owns |this|. Saved so we can close it
+ // later.
+ WebContentsModalDialog* window_;
// Holds the HTML to display in the constrained dialog.
scoped_ptr<content::WebContents> web_contents_;